@@ -27,32 +27,24 @@ class Mc1Test(unittest.TestCase):
         bad_silicon.append("Si", [0.1, 0.1, 0.15])
         bad_silicon.append("Si", [0.1, 0.333, 0.15])
         self.assertEqual(len(bad_silicon), 4)
-        data = pd.DataFrame(
-            {"structure": {
-                "good": good_silicon,
-                "bad": bad_silicon
-            }
-            }
-        )
+        data = pd.DataFrame({"structure": {"good": good_silicon, "bad": bad_silicon}})
 
-        experiment = OqmdDFTonMC1(poll_time=30, timeout=150, prefix_append=str(test_uuid))
+        experiment = OqmdDFTonMC1(
+            poll_time=30, timeout=150, prefix_append=str(test_uuid)
+        )
         experiment.submit(data)
         status = experiment.monitor()
         results = experiment.get_results()
 
-        self.assertAlmostEqual(results.loc['good', 'delta_e'], 0, 5)
-        self.assertIsNone(results.loc['bad', 'result'])
+        self.assertAlmostEqual(results.loc["good", "delta_e"], 0, 5)
+        self.assertIsNone(results.loc["bad", "result"])
 
         # Test cleanup functionality
         experiment.poll_time = 1
         experiment.timeout = 1
-        old_paths = experiment.current_data['path']
+        old_paths = experiment.current_data["path"]
         data = pd.DataFrame(
-            {"structure": {
-                "newgood": good_silicon,
-                "newbad": bad_silicon
-            }
-            }
+            {"structure": {"newgood": good_silicon, "newbad": bad_silicon}}
         )
         experiment.submit(data)
         experiment.monitor()
@@ -69,13 +61,16 @@ class Mc1Test(unittest.TestCase):
         bad_silicon.append("Si", [0.1, 0.333, 0.15])
         self.assertEqual(len(bad_silicon), 4)
         data = pd.DataFrame(
-            {"structure": {
-                "good": good_silicon,
-                "bad": bad_silicon,
-            }
+            {
+                "structure": {
+                    "good": good_silicon,
+                    "bad": bad_silicon,
+                }
             }
         )
-        experiment = OqmdDFTonMC1(poll_time=30, timeout=150, prefix_append="camd-cache-test")
+        experiment = OqmdDFTonMC1(
+            poll_time=30, timeout=150, prefix_append="camd-cache-test"
+        )
         # This generates the data if needed in the future
         # experiment.submit(data)
         # status = experiment.monitor()
@@ -84,28 +79,25 @@ class Mc1Test(unittest.TestCase):
         experiment.update_current_data(data)
         results = experiment.fetch_cached(data)
 
-        self.assertAlmostEqual(results.loc['good', 'delta_e'], 0, 5)
-        self.assertIsNone(results.loc['bad', 'result'])
-        self.assertEqual(results.loc['bad', 'status'], "FAILED")
+        self.assertAlmostEqual(results.loc["good", "delta_e"], 0, 5)
+        self.assertIsNone(results.loc["bad", "result"])
+        self.assertEqual(results.loc["bad", "status"], "FAILED")
 
     @unittest.skipUnless(CAMD_DFT_TESTS, SKIP_MSG)
     def test_structure_suite(self):
-        mp_ids = ["mp-702",
-                  "mp-1953",
-                  "mp-1132",
-                  "mp-8409",
-                  "mp-872"]
+        mp_ids = ["mp-702", "mp-1953", "mp-1132", "mp-8409", "mp-872"]
         with MPRester() as mpr:
-            structure_dict = {mp_id: mpr.get_structure_by_material_id(mp_id)
-                              for mp_id in mp_ids}
+            structure_dict = {
+                mp_id: mpr.get_structure_by_material_id(mp_id) for mp_id in mp_ids
+            }
         data = pd.DataFrame({"structure": structure_dict})
 
         experiment = OqmdDFTonMC1(poll_time=25)
         experiment.submit(data)
         status = experiment.monitor()
         results = experiment.get_results()
-        self.assertTrue(all(results['status'] == "SUCCEEDED"))
+        self.assertTrue(all(results["status"] == "SUCCEEDED"))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
